@@ -8,6 +8,7 @@
 
 """
 
+import datetime
 from enum import Enum
 
 from .utils.sync import sync
@@ -174,6 +175,7 @@ class Episode(Video):
         self.credential = credential
         self.epid = epid
         bvid = sync(self.get_episode_info())["epInfo"]["bvid"]
+        self.video_class = Video(bvid=bvid, credential=credential)
         super().__init__(bvid=bvid)
         self.bangumi = self.get_bangumi_from_episode()
         self.set_aid = self.set_aid_e
@@ -191,6 +193,9 @@ class Episode(Video):
     def set_bvid_e(self, bvid: str):
         print("Set bvid is not allowed in Episode")
 
+    async def get_cid(self):
+        return await super().get_cid(0)
+
     def get_bangumi(self):
         """
         获取对应的番剧
@@ -247,3 +252,58 @@ class Episode(Video):
         info = sync(self.get_episode_info())
         ssid = info["mediaInfo"]["season_id"]
         return Bangumi(ssid=ssid)
+    
+    async def get_download_url(self):
+        """
+        获取番剧剧集下载信息。
+
+        Returns:
+            dict: 调用 API 返回的结果。
+        """
+        url = API["info"]["playurl"]["url"]
+        if True:
+            params = {
+                "avid": self.get_aid(),
+                "cid": await self.get_cid(),
+                "qn": "127",
+                "otype": "json",
+                "fnval": 4048,
+                "fourk": 1,
+            }
+        return await request("GET", url, params=params, credential=self.credential)
+
+    async def get_danmaku_xml(self):
+        """
+        获取所有弹幕的 xml 源文件（非装填）
+
+        Returns:
+            文件源
+        """
+        return await self.video_class.get_danmaku_xml(0)
+
+    async def get_danmaku_view(self):
+        """
+        获取弹幕设置、特殊弹幕、弹幕数量、弹幕分段等信息。
+
+        Returns:
+            dict: 二进制流解析结果
+        """
+        return await self.video_class.get_danmaku_view(0)
+
+    async def get_danmakus(self, date: datetime.date = None):
+        """
+        获取弹幕
+
+        Returns:
+            dict[Danmaku]: 弹幕列表
+        """
+        return await self.video_class.get_danmakus(0, date)
+
+    async def get_history_danmaku_index(self, date: datetime.date = None):
+        """
+        获取特定月份存在历史弹幕的日期。
+
+        Returns:
+            None | List[str]: 调用 API 返回的结果。不存在时为 None。
+        """
+        return await self.video_class.get_history_danmaku_index(0, date)
